==> mrpt_1.0.2.orig.tar.gz: mrpt-1.0.2/doc/doxygen-pages/lib_mrpt_reactivenav.h <==
/* +---------------------------------------------------------------------------+
   |                 The Mobile Robot Programming Toolkit (MRPT)               |
   |                                                                           |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2013, Individual contributors, see AUTHORS file        |
   | Copyright (c) 2005-2013, MAPIR group, University of Malaga                |
   | Copyright (c) 2012-2013, University of Almeria                            |
   | All rights reserved.                                                      |
   |                                                                           |
   | Redistribution and use in source and binary forms, with or without        |
   | modification, are permitted provided that the following conditions are    |
   | met:                                                                      |
   |    * Redistributions of source code must retain the above copyright       |
   |      notice, this list of conditions and the following disclaimer.        |
   |    * Redistributions in binary form must reproduce the above copyright    |
   |      notice, this list of conditions and the following disclaimer in the  |
   |      documentation and/or other materials provided with the distribution. |
   |    * Neither the name of the copyright holders nor the                    |
   |      names of its contributors may be used to endorse or promote products |
   |      derived from this software without specific prior written permission.|
   |                                                                           |
   | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       |
   | 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED |
   | TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR|
   | PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE |
   | FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL|
   | DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR|
   |  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)       |
   | HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,       |
   | STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN  |
   | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE           |
   | POSSIBILITY OF SUCH DAMAGE.                                               |
   +---------------------------------------------------------------------------+ */

/** \defgroup mrpt_reactivenav_grp [mrpt-reactivenav]

<small> <a href="index.html#libs">Back to list of all libraries</a> | <a href="modules.html" >See all modules</a> </small>
<br>

<h2>Library <code>mrpt-reactivenav</code></h2>
<hr>

This library implements:

<ul>

<li>Holonomic navigation algorithms:  
   Virtual Force Fields (VFF), Nearness Diagram (ND), ... 
   See mrpt::reactivenav::CAbstractHolonomicReactiveMethod </li>


<li>A complex reactive navigator: Using space transformations (PTGs) to drive
  a robot using an internal simpler holonomic algorithm. See mrpt::reactivenav::CReactiveNavigationSystem </li>

<li>A number of different PTGs: See mrpt::reactivenav::CParameterizedTrajectoryGenerator</li>

</ul>

See the full list of classes in mrpt::reactivenav, or the online
page http://www.mrpt.org/Application:ReactiveNavigationDemo for a discussion
of a working application (see MRPT/apps/ReactiveNavigationDemo).


*/

==> mrpt_1.2.2.orig.tar.gz: mrpt-1.2.2/doc/doxygen-pages/lib_mrpt_reactivenav.h <==
/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
   | See: http://www.mrpt.org/Authors - All rights reserved.                   |
   | Released under BSD License. See details in http://www.mrpt.org/License    |
   +---------------------------------------------------------------------------+ */


/** \defgroup mrpt_reactivenav_grp [mrpt-reactivenav]

<small> <a href="index.html#libs">Back to list of all libraries</a> | <a href="modules.html" >See all modules</a> </small>
<br>

<h2>Library <code>mrpt-reactivenav</code></h2>
<hr>

This library implements:

<ul>

<li>Holonomic navigation algorithms:  
   Virtual Force Fields (VFF), Nearness Diagram (ND), ... 
   See mrpt::reactivenav::CAbstractHolonomicReactiveMethod </li>


<li>A complex reactive navigator: Using space transformations (PTGs) to drive
  a robot using an internal simpler holonomic algorithm. See mrpt::reactivenav::CReactiveNavigationSystem </li>

<li>A number of different PTGs: See mrpt::reactivenav::CParameterizedTrajectoryGenerator</li>

</ul>

See the full list of classes in mrpt::reactivenav, or the online
page http://www.mrpt.org/Application:ReactiveNavigationDemo for a discussion
of a working application (see MRPT/apps/ReactiveNavigationDemo).


*/
